/**
 * version_string and program_name are used by siege
 * and configure; author_name and email_address are 
 * used by configure to dynamically assign those values 
 * to documentation files.
 */
const char *version_string = "2.65";
const char *program_name   = "siege";
const char *author_name    = "Jeffrey Fulmer";
const char *email_address  = "jeff@joedog.org";

